@@ -7,7 +7,11 @@ from itertools import zip_longest
 
 from lxml import etree
 from zeep.exceptions import Fault
-from PyPDF2 import PdfFileReader, PdfFileWriter
+
+try:
+    from PyPDF2 import PdfReader, PdfWriter
+except ImportError:
+    from PyPDF2 import PdfFileReader as PdfReader, PdfFileWriter as PdfWriter
 
 from trytond.i18n import gettext
 from trytond.pool import Pool, PoolMeta
@@ -25,6 +29,14 @@ from .exceptions import DPDError
 TRACKING_URL = 'https://tracking.dpd.de/status/%(code)s/parcel/%(reference)s'
 
 
+def iter_pdf_pages(document):
+    if hasattr(document, 'pages'):
+        yield from document.pages
+    else:
+        for i in range(document.getNumPages()):
+            yield document.getPage(i)
+
+
 class Package(metaclass=PoolMeta):
     __name__ = 'stock.package'
 
@@ -166,11 +178,14 @@ class CreateDPDShipping(Wizard):
 
         labels = []
         labels_pdf = BytesIO(shipment_response.parcellabelsPDF)
-        reader = PdfFileReader(labels_pdf)
-        for page_num in range(reader.getNumPages()):
-            new_pdf = PdfFileWriter()
+        reader = PdfReader(labels_pdf)
+        for page in iter_pdf_pages(reader):
+            new_pdf = PdfWriter()
             new_label = BytesIO()
-            new_pdf.addPage(reader.getPage(page_num))
+            if hasattr(new_pdf, 'add_page'):
+                new_pdf.add_page(page)
+            else:
+                new_pdf.addPage(page)
             new_pdf.write(new_label)
             labels.append(new_label)
 
@@ -222,8 +237,8 @@ class CreateDPDShipping(Wizard):
                 phone = mechanism.value
             if mechanism.type == 'email' and not email:
                 email = mechanism.value
-        if phone:
-            shipping_party['phone'] = phone[:30]
+        if len(phone) <= 30:
+            shipping_party['phone'] = phone
         if len(email) <= 50:
             shipping_party['email'] = email
 
